var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_07.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_down1 = [
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_07.xml#Introduction',
'whats_new_07.xml#12-29',
'whats_new_07.xml#12-25',
'whats_new_07.xml#12-21',
'whats_new_07.xml#12-08',
'whats_new_07.xml#12-05',
'whats_new_07.xml#12-04',
'whats_new_07.xml#12-03',
'whats_new_07.xml#12-02',
'whats_new_07.xml#11-29',
'whats_new_07.xml#11-23',
'whats_new_07.xml#11-18',
'whats_new_07.xml#11-06',
'whats_new_07.xml#11-05',
'whats_new_07.xml#11-04',
'whats_new_07.xml#11-03',
'whats_new_07.xml#11-02',
'whats_new_07.xml#11-01',
'whats_new_07.xml#10-30',
'whats_new_07.xml#10-27',
'whats_new_07.xml#10-23',
'whats_new_07.xml#10-22',
'whats_new_07.xml#10-16',
'whats_new_07.xml#10-13',
'whats_new_07.xml#10-05',
'whats_new_07.xml#10-02',
'whats_new_07.xml#09-06',
'whats_new_07.xml#08-09',
'whats_new_07.xml#08-07',
'whats_new_07.xml#07-30',
'whats_new_07.xml#07-29',
'whats_new_07.xml#07-28',
'whats_new_07.xml#07-26',
'whats_new_07.xml#07-26.07-26',
'whats_new_07.xml#07-26.07-25',
'whats_new_07.xml#07-23',
'whats_new_07.xml#07-22',
'whats_new_07.xml#07-21',
'whats_new_07.xml#07-20',
'whats_new_07.xml#07-19',
'whats_new_07.xml#07-18',
'whats_new_07.xml#07-14',
'whats_new_07.xml#07-13',
'whats_new_07.xml#06-22',
'whats_new_07.xml#06-20',
'whats_new_07.xml#06-14',
'whats_new_07.xml#05-26',
'whats_new_07.xml#05-25',
'whats_new_07.xml#05-24',
'whats_new_07.xml#05-22',
'whats_new_07.xml#05-08',
'whats_new_07.xml#05-05',
'whats_new_07.xml#04-19',
'whats_new_07.xml#04-17',
'whats_new_07.xml#04-14',
'whats_new_07.xml#04-11',
'whats_new_07.xml#04-11.04-11',
'whats_new_07.xml#04-11.04-10',
'whats_new_07.xml#04-11.04-07',
'whats_new_07.xml#04-11.04-06',
'whats_new_07.xml#04-11.04-05',
'whats_new_07.xml#03-31',
'whats_new_07.xml#03-31.03-31',
'whats_new_07.xml#03-31.03-30',
'whats_new_07.xml#03-29',
'whats_new_07.xml#03-20',
'whats_new_07.xml#03-15',
'whats_new_07.xml#03-15.03-15',
'whats_new_07.xml#03-15.03-14',
'whats_new_07.xml#03-15.03-13',
'whats_new_07.xml#03-09',
'whats_new_07.xml#03-09.03-28',
'whats_new_07.xml#03-09.02-27',
'whats_new_07.xml#03-09.02-22',
'whats_new_07.xml#03-09.02-17',
'whats_new_07.xml#03-09.02-16',
'whats_new_07.xml#03-09.02-15',
'whats_new_07.xml#02-06',
'whats_new_07.xml#02-04',
'whats_new_07.xml#02-03',
'whats_new_07.xml#02-02',
'whats_new_07.xml#02-01',
'whats_new_07.xml#01-29'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
